==> multienv-0.3.3.tar.gz: multienv-0.3.3/src/multienv/pyenvs.py <==
"""
pyenvs command entrypoint
"""
import logging

from argparse import ArgumentParser, Namespace
from pathlib import Path

import yaml

from multienv._pyenvs_config_formatter import Formatters
from multienv._pyenvs_config_input_std import Configuration

LOG = logging.getLogger(__name__)


def _info(ns: Namespace):
    """info
    """
    LOG.info("info")


def _config(ns: Namespace):
    """config
    """
    LOG.info("config")

    extension = ns.file.split('.')[-1]
    output_dir = Path(Path.cwd(), ns.output)

    if extension in ['yml']:
        LOG.info('open configuration file %s', ns.file)
        with open(ns.file, encoding=ns.encoding) as s:
            content = yaml.safe_load(s)
            configuration = Configuration.from_dict(content)

            LOG.debug('open configuration file content: %s', configuration)
            for req_formatter in configuration.formatters:
                for supported_formatter in Formatters:
                    if supported_formatter.test(req_formatter):
                        supported_formatter.write(configuration, output_dir)


    else:
        raise ValueError(f'unsupported configuration format {extension}')


def _create_parser() -> ArgumentParser:

    # parse argument line
    parser = ArgumentParser(description='Multi environment management.')

    subparsers = parser.add_subparsers(dest='CMD', help='available commands')

    subparsers.add_parser('info', help='get general info')

    parser_config = subparsers.add_parser('config', help='generates environment configurations')
    parser_config.add_argument('file',
                               nargs='?',
                               help="path to the configuration file",
                               default="multienv.yml")
    parser_config.add_argument('--encoding',
                               nargs='?',
                               help='the configuration file encoding (default to utf-8)',
                               default='utf-8')
    parser_config.add_argument('--output',
                               nargs='?',
                               help='the environment file output directory',
                               default='.')

    return parser

def config(configuration: Configuration, formatter: Formatters) -> list:
    """Builds the environment set mapping the configuration using the given formatter."""
    return formatter.build(configuration)


def entrypoint():
    """The pyenvs command entrypoint."""

    commands = {
        'info': _info,
        'config': _config
    }

    ns: Namespace = _create_parser().parse_args()

    commands[ns.CMD](ns)

==> multienv-0.3.5.tar.gz: multienv-0.3.5/src/multienv/pyenvs.py <==
"""
pyenvs command entrypoint
"""
import logging

from argparse import ArgumentParser, Namespace
from pathlib import Path

import yaml

from multienv._pyenvs_config_formatter import Formatters
from multienv._pyenvs_config_input_std import Configuration

LOG = logging.getLogger(__name__)


def _info(ns: Namespace):
    """info
    """
    LOG.info("info")


def _dependencies(ns: Namespace):
    """config
    """
    LOG.info("dependencies")

    extension = ns.file.split('.')[-1]
    output_dir = Path(Path.cwd(), ns.output)

    if extension in ['yml']:
        LOG.info('open configuration file %s', ns.file)
        with open(ns.file, encoding=ns.encoding) as s:
            content = yaml.safe_load(s)
            configuration = Configuration.from_dict(content)

            LOG.debug('open configuration file content: %s', configuration)
            for req_formatter in configuration.formatters:
                for supported_formatter in Formatters:
                    if supported_formatter.test(req_formatter):
                        supported_formatter.write(configuration, output_dir)


    else:
        raise ValueError(f'unsupported configuration format {extension}')


def _create_parser() -> ArgumentParser:

    # parse argument line
    parser = ArgumentParser(description='Multi environment management.')

    subparsers = parser.add_subparsers(dest='CMD', help='available commands')

    subparsers.add_parser('info', help='get general info')

    parser_config = subparsers.add_parser(name='dependencies',
                                          help='generates environment configurations',
                                          aliases=['deps'])
    parser_config.add_argument('file',
                               nargs='?',
                               help="path to the configuration file",
                               default="multienv.yml")
    parser_config.add_argument('--encoding',
                               nargs='?',
                               help='the configuration file encoding (default to utf-8)',
                               default='utf-8')
    parser_config.add_argument('--output',
                               nargs='?',
                               help='the environment file output directory',
                               default='.')

    return parser

def dependencies(configuration: Configuration, formatter: Formatters) -> list:
    """Builds the environment set mapping the configuration using the given formatter."""
    return formatter.build(configuration)


def entrypoint():
    """The pyenvs command entrypoint."""

    commands = {
        'info': _info,
        'dependencies': _dependencies
    }

    ns: Namespace = _create_parser().parse_args()

    commands[ns.CMD](ns)
